@@ -1,17 +1,18 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "copilot-chat" "3.0.0"
+(define-package "copilot-chat" "20251016.754"
   "Copilot chat interface."
-  '((request       "0.3.2")
-    (markdown-mode "2.6")
-    (emacs         "27.1")
-    (magit         "4.0.0")
+  '((emacs         "29.1")
+    (aio           "1.0")
+    (request       "0.3.2")
     (transient     "0.8.3")
-    (org           "9.4.6")
     (polymode      "0.2.2")
-    (shell-maker   "0.76.2"))
+    (org           "9.4.6")
+    (markdown-mode "2.6")
+    (shell-maker   "0.76.2")
+    (mcp           "0.1.0"))
   :url "https://github.com/chep/copilot-chat.el"
-  :commit "765c08b45a6a35abaa67cd976fed37ab1b07370c"
-  :revdesc "765c08b45a6a"
+  :commit "24719dbc3f68e8c467b678edda48b7cf64b30360"
+  :revdesc "24719dbc3f68"
   :keywords '("convenience" "tools")
   :authors '(("cedric.chepied" . "cedric.chepied@gmail.com"))
   :maintainers '(("cedric.chepied" . "cedric.chepied@gmail.com")))
